@@ -147,16 +147,6 @@ def connect(*args, **kwargs):
         new_config = read_option_files(**kwargs)
         return connect(**new_config)
 
-    if all(['fabric' in kwargs, 'failover' in kwargs]):
-        raise InterfaceError("fabric and failover arguments can not be used")
-
-    if 'fabric' in kwargs:
-        if 'pool_name' in kwargs:
-            raise AttributeError("'pool_name' argument is not supported with "
-                                 " MySQL Fabric. Use 'pool_size' instead.")
-        from .fabric import connect as fabric_connect
-        return fabric_connect(*args, **kwargs)
-
     # Failover
     if 'failover' in kwargs:
         return _get_failover_connection(**kwargs)
@@ -170,13 +160,13 @@ def connect(*args, **kwargs):
         # No pooling
         pass
 
-    use_pure = kwargs.setdefault('use_pure', False)
-
-    try:
-        del kwargs['use_pure']
-    except KeyError:
-        # Just making sure 'use_pure' is not kwargs
-        pass
+    # Use C Extension by default
+    use_pure = kwargs.get('use_pure', False)
+    if 'use_pure' in kwargs:
+        del kwargs['use_pure']  # Remove 'use_pure' from kwargs
+        if not use_pure and not HAVE_CEXT:
+            raise ImportError("MySQL Connector/Python C Extension not "
+                              "available")
 
     if HAVE_CEXT and not use_pure:
         return CMySQLConnection(*args, **kwargs)
