@@ -160,7 +160,8 @@ class CMySQLConnection(MySQLConnectionAbstract):
             'port': self._port,
             'client_flags': self._client_flags,
             'unix_socket': self._unix_socket,
-            'compress': self.isset_client_flag(ClientFlag.COMPRESS)
+            'compress': self.isset_client_flag(ClientFlag.COMPRESS),
+            'ssl_disabled': True
         }
 
         if not self._ssl_disabled:
@@ -169,6 +170,8 @@ class CMySQLConnection(MySQLConnectionAbstract):
                 'ssl_cert': self._ssl.get('cert'),
                 'ssl_key': self._ssl.get('key'),
                 'ssl_verify_cert': self._ssl.get('verify_cert') or False,
+                'ssl_verify_identity':
+                    self._ssl.get('verify_identity') or False,
                 'ssl_disabled': self._ssl_disabled
             })
 
